==> gtkballs-2.2.0.tar.gz: gtkballs-2.2.0/src/interface.h <==
/* GtkBalls
 * Copyright (C) 1998-1999 Eugene V. Morozov
 * Modifyed in 2001 by drF_ckoff
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */
#ifndef __GTKBALLS_INTERFACE_H
#define __GTKBALLS_INTERFACE_H

#include <gtk/gtk.h>

extern GtkWidget *Hi_score_label,*User_score_label;

void show_hall_of_fame(GtkWidget *widget, gpointer data);
void about(GtkWidget *widget, gpointer data);
void simple_message_box(gchar *message, gchar *label);
gint delete_event(GtkWidget *widget, gpointer data);
void destroy(GtkWidget *widget, gpointer data);
gint calculate_board_coord_x(gint window_coord);
gint calculate_board_coord_y(gint window_coord);
void update_rectangle(GtkWidget *widget, gint x, gint y, gint w, gint h);
void set_hi_score_label(void);
void set_user_score_label(void);
gint destroy_lines(GtkWidget *widget, GdkPixmap *pixmap, gint count_score);
gchar *input_name_dialog(void);
void save_game_cb(GtkWidget *widget, gpointer data);
void load_game_cb(GtkWidget *widget, gpointer data);
void show_hide_next_balls(gboolean show);
void rules_dialog(void);

#endif

==> gtkballs_3.0.1.orig.tar.gz: gtkballs-3.0.1/src/interface.h <==
/* GtkBalls
 * Copyright (C) 1998-1999 Eugene V. Morozov
 * Modifyed in 2001 by drF_ckoff
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */
#ifndef __GTKBALLS_INTERFACE_H
#define __GTKBALLS_INTERFACE_H

extern GtkWidget *Hi_score_label,*User_score_label;

void show_hall_of_fame(GtkWidget *widget, gpointer data);
void about(GtkWidget *widget, gpointer data);
void simple_message_box(gchar *message);
gint calculate_board_coord_x(gint window_coord);
gint calculate_board_coord_y(gint window_coord);
void update_rectangle(GtkWidget *widget, gint x, gint y, gint w, gint h);
void set_hi_score_label(void);
void set_user_score_label(void);
gint destroy_lines(GtkWidget *widget, GdkPixmap *pixmap, gint count_score);
gchar *input_name_dialog(void);
void save_game_cb(GtkWidget *widget, gpointer data);
void load_game_cb(GtkWidget *widget, gpointer data);
void show_hide_next_balls(gboolean show);
void rules_dialog(void);

#endif
